@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -59,7 +59,7 @@ void authfail_report()
    }
 
    sprintf(authfail_in,"%s/authfail.log",TempDir);
-   sprintf(per,"%s/period",dirname);
+   sprintf(per,"%s/sarg-period",dirname);
    sprintf(report,"%s/authfail.html",dirname);
 
    sprintf(csort,"sort -b -T %s -k 3,3 -k 5,5 -o '%s' '%s'", TempDir, authfail_in, tmp4);
