@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -37,6 +37,8 @@ void ccharset()
    else if(strcmp(CharSet,"Latin5") == 0) strcpy(CharSet,"ISO-8859-9");
    else if(strcmp(CharSet,"Latin6") == 0) strcpy(CharSet,"ISO-8859-10");
    else if(strcmp(CharSet,"Windows-1251") == 0) strcpy(CharSet,"Windows-1251");
+   else if(strcmp(CharSet,"Japan") == 0) strcpy(CharSet,"EUC-JP");
    else if(strcmp(CharSet,"Koi8-r") == 0) strcpy(CharSet,"KOI8-R");
+   else if(strcmp(CharSet,"UTF-8") == 0) strcpy(CharSet,"UTF-8");
    return;
 }
