@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -55,7 +55,7 @@ void gen_denied_report()
       return;
    }
 
-   sprintf(per,"%s/period",dirname);
+   sprintf(per,"%s/sarg-period",dirname);
    sprintf(report,"%s/denied.html",dirname);
 
    if ((fp_in = fopen(per, "r")) == 0) {
