@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -57,7 +57,7 @@ void download_report()
    strcpy(wdirname,dirname);
    sprintf(report,"%s/download.html",wdirname);
    strcat(wdirname,"/");
-   strcat(wdirname,"period");
+   strcat(wdirname,"sarg-period");
 
    if ((fp_in = fopen(wdirname, "r")) == 0) {
       fprintf(stderr, "SARG: (download) %s: %s\n",text[45],wdirname);
@@ -115,7 +115,7 @@ void download_report()
       getword(user,buf,' ');
       getword(ip,buf,' ');
       getword(url,buf,' ');
-
+  
       if((str=(char *) strstr(user, "_")) != (char *) NULL ) {
          if((str=(char *) strstr(str+1, "_")) != (char *) NULL )
             fixip(user);
