@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -48,11 +48,11 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    strcpy(top2,dirname);
    strcpy(top3,dirname);
    strcpy(tusr,dirname);
-   strcat(wger,"/general");
+   strcat(wger,"/sarg-general");
    strcat(top1,"/top");
    strcat(top2,"/top.tmp");
    strcat(top3,"/report");
-   strcat(tusr,"/users");
+   strcat(tusr,"/sarg-users");
 
    if((fp_in=fopen(wger,"r"))==NULL) {
       fprintf(stderr, "SARG: (email) %s: %s\n",text[45],wger);
@@ -176,7 +176,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
  */
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/period");
+   strcat(arqper,"/sarg-period");
 
    if ((fp_in = fopen(arqper, "r")) == 0){
       fprintf(stderr, "SARG: (email) %s: %s\n",text[45],arqper);
@@ -316,7 +316,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
       system(buf);
    }
  
-   sprintf(csort,"rm -r %s/sarg_tmp",TempDir);
+   sprintf(csort,"rm -rf %s/sarg",TempDir);
    system(csort);
 
    return (0);
