@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -29,10 +29,19 @@ int vhexclude(char *excludefile, char *url)
 {
 
    char whost[1024];
-   char str[strlen(excludefile)];
-   char wurl[strlen(url)];
-   char wurl2[strlen(url)];
+   char *str;
+   char *wurl;
+   int len = strlen(excludefile);
 
+   if((str=(char *) malloc(len+1))==NULL) {
+         fprintf(stderr, "SARG: %s (%ld):\n",text[59], len);
+         exit(1);
+   }
+   len = strlen(url);
+   if((wurl=(char *) malloc(len+1))==NULL) {
+         fprintf(stderr, "SARG: %s (%ld):\n",text[59], len);
+         exit(1);
+   }
    whost[0]='\0';
    strcpy(str,excludefile);
    strcpy(wurl,url);
@@ -45,17 +54,24 @@ int vhexclude(char *excludefile, char *url)
    }
 
    while(strcmp(whost,"*END*") != 0) {
-      if(strcmp(wurl,whost) == 0)
+      if(strcmp(wurl,whost) == 0) {
+	 free(wurl);
+	 free(str);
          return(0);
+      }
       if(strchr(whost,'*') != 0) {
          getword(warea,whost,'.');
          getword(warea,wurl,'.');
-         if(strcmp(wurl,whost) == 0)
+         if(strcmp(wurl,whost) == 0) {
+	    free(wurl);
+	    free(str);
             return(0);
+	 }
       }
       getword(whost,str,' ');
    }
-
+   free(wurl);
+   free(str);
    return(1);
 }
 
