@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -776,6 +776,11 @@ void parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"squid24") != 0) {
+         squid24++;
+         return;
+      }
+
       if(strstr(buf,"byte_cost") != 0) {
          getword(wbuf,buf,' ');
          cost=atol(buf);
@@ -803,16 +808,16 @@ void getconf()
 
    while (fgets(buf, MAXLEN, fp_in) != NULL) {
       if(strstr(buf,"\n") != 0)
-         buf[strlen(buf)-1]='\n';
+         buf[strlen(buf)-1]='\0';
 
       if(debugm)
          printf("SYSCONFDIR %s",buf);
 
-      if(strncmp(buf,"#",1) == 0 || strncmp(buf,"\n",1) == 0)
+      if(strncmp(buf,"#",1) == 0 || strlen(buf) < 1)
          continue;
 
       if(debugz)
-         printf("SARG: TAG: %s",buf);
+         printf("SARG: TAG: %s\n",buf);
 
       parmtest(buf);
 
