@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -36,7 +36,8 @@ int gray;
 int silver;
 int black;
 int x1;
-char *font1 = SYSCONFDIR"/fonts/FreeSans.ttf";
+//char *font1 = SYSCONFDIR"/fonts/FreeSans.ttf";
+char *font1 = SYSCONFDIR"/fonts/DejaVuSans.ttf";
 char s[15];
 
 #if defined(HAVE_GD) && defined(HAVE_ICONV_H) && defined(gdFTEX_Unicode)
@@ -436,8 +437,8 @@ void greport_day(char *user, int *iprel, int *ipuser)
          bar(tot);
          strcpy(oday,day);
          tot=0;
-      } else
-         tot=tot+my_atoll(bytes);
+      }
+      tot=tot+my_atoll(bytes);
    }
 
    if(tot) {
@@ -454,5 +455,6 @@ void greport_day(char *user, int *iprel, int *ipuser)
    unlink(tmp5);
  
 #endif  
+
    return;
 }
