@@ -99,6 +99,8 @@ char user[MAXLEN];
 char period[MAXLEN];
 char msg[1024];
 char per_hour[128];
+char code[MAXLEN];
+char code2[MAXLEN];
 char tmp[MAXLEN];
 char tmp2[MAXLEN];
 char tmp3[MAXLEN];
@@ -318,6 +320,12 @@ int  realtime_access_log_lines;
 int  realt;
 int  x, y;
 int  rc;
+int  ntopsites;
+int  nsitesusers;
+int  nrepday;
+int  ndownload;
+int  ntopuser;
+int  squid24;
 long l1, l2;
 float perc;
 
