@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -73,8 +73,6 @@ int main(argc,argv)
    char tam[255];
    char fun[255];
    char wuser[MAXLEN]; 
-   char code[MAXLEN];
-   char code2[MAXLEN];
    char smartfilter[MAXLEN];
    char dia[128]; 
    char wdata[128];
@@ -145,6 +143,7 @@ int main(argc,argv)
    ExternalCSSFile[0]='\0';
    SquidGuardLogFormat[0]='\0';
    SquidGuardLogAlternate[0]='\0';
+   arq[0]='\0';
 
    strcpy(AccessLog,"/usr/local/squid/var/logs/access.log");
    sprintf(ExcludeCodes,"%s/exclude_codes",SYSCONFDIR);
@@ -182,7 +181,7 @@ int main(argc,argv)
    strcpy(LongUrl,"no");
    strcpy(language,"English");
    strcpy(FontFace,"Verdana,Tahoma,Arial");
-   strcpy(datetimeby,"bytes");
+   strcpy(datetimeby,"elap");
    strcpy(CharSet,"ISO-8859-1");
    strcpy(Privacy,"no");
    strcpy(PrivacyString,"***.***.***.***");
@@ -212,7 +211,7 @@ int main(argc,argv)
    strcpy(NtlmUserFormat,"domainname+username");
    strcpy(IndexTree,"file");
    strcpy(RealtimeTypes,"GET,PUT,CONNECT");
-   strcpy(RealtimeUnauthRec,"ignore");
+   strcpy(RealtimeUnauthRec,"show");
    strcpy(SquidguardIgnoreDate,"off");
    strcpy(DansguardianIgnoreDate,"off");
    strcpy(DataFileUrl,"ip");
@@ -274,6 +273,8 @@ int main(argc,argv)
    realtime_access_log_lines=1000;
    cost=0.01;
    nocost=50000000;
+   ndownload=0;
+   squid24=0;
 
    bzero(IncludeUsers, MAXLEN);
    bzero(ExcludeString, MAXLEN);
@@ -415,7 +416,7 @@ int main(argc,argv)
          }
     
    if(access(ConfigFile, R_OK) == 0)
-      getconf(debugm, ConfigFile, AccessLog, debug, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, PasswdFile, TempDir, OutputDir, OutputEmail, Ip2Name, TopuserSortField, UserSortField, TopuserSortOrder, UserSortOrder, UserAgentLog, ExcludeHosts, DateFormat, ExcludeUsers, PerUserLimitFile, PerUserLimit, UserIp, MaxElapsed);
+      getconf();
    
    if(realt) {
       realtime();
@@ -525,9 +526,9 @@ int main(argc,argv)
    strcpy(tmp2,tmp);
 
    if(strlen(email) > 0) {
-      sprintf(wtemp2,"%s/sarg_tmp",tmp2);
+      sprintf(wtemp2,"%s/sarg",tmp2);
       my_mkdir(wtemp2);
-      strcat(tmp2,"/sarg_tmp");
+      strcat(tmp2,"/sarg");
       strcpy(outdir,tmp2);
       strcat(outdir,"/");
     }
@@ -640,31 +641,36 @@ int main(argc,argv)
       sprintf(msg,"sarg %s: %s",text[73],VERSION);
       debuga(msg);
    }
-#if defined(RLIMIT_NOFILE)
-   getrlimit (RLIMIT_NOFILE, &rl);
-#else #if defined(RLIMIT_OFILE)
-   getrlimit (RLIMIT_OFILE, &rl);
-#endif
-   l1 = rl.rlim_cur;
-   l2 = rl.rlim_max;
 
-   rl.rlim_cur = atol(Ulimit);
-   rl.rlim_max = atol(Ulimit);
+   if (strlen(Ulimit) > 0) {
 #if defined(RLIMIT_NOFILE)
-   if(setrlimit (RLIMIT_NOFILE, &rl) == -1) {
+      getrlimit (RLIMIT_NOFILE, &rl);
 #else #if defined(RLIMIT_OFILE)
-   if(setrlimit (RLIMIT_OFILE, &rl) == -1) {
+      getrlimit (RLIMIT_OFILE, &rl);
 #endif
-      sprintf(msg,"setrlimit error - %s\n",strerror(errno));
-      debuga(msg);
+      l1 = rl.rlim_cur;
+      l2 = rl.rlim_max;
+
+      if(Ulimit[0] != '\0') {
+         rl.rlim_cur = atol(Ulimit);
+         rl.rlim_max = atol(Ulimit);
+ #if defined(RLIMIT_NOFILE)
+         if(setrlimit (RLIMIT_NOFILE, &rl) == -1) {
+ #else #if defined(RLIMIT_OFILE)
+         if(setrlimit (RLIMIT_OFILE, &rl) == -1) {
+ #endif
+            sprintf(msg,"setrlimit error - %s\n",strerror(errno));
+            debuga(msg);
+         }
+      }
+
+      if(debug) {
+         sprintf(msg,"Maximum file descriptor: cur=%ld max=%ld, changed to cur=%ld max=%ld",l1,l2,rl.rlim_cur,rl.rlim_max);
+         debuga(msg);
+      }
    }
 
-   if(debug) {
-      sprintf(msg,"Maximum file descriptor: cur=%ld max=%ld, changed to cur=%ld max=%ld",l1,l2,rl.rlim_cur,rl.rlim_max);
-      debuga(msg);
-   }
-
-   if(UserTabFile[0] != '\0') {
+   if (UserTabFile[0] != '\0') {
       if(debug) {
          sprintf(msg,"%s: %s",text[86],UserTabFile);
          debuga(msg);
@@ -683,20 +689,20 @@ int main(argc,argv)
       strncat(userfile,":",1);
       z1=0;
       z2=1;
-      while(fgets(buf,MAXLEN,fp_usr)!=NULL){
-        buf[strlen(buf)-1]='\0';
-        if(strstr(buf,"\r") != 0) buf[strlen(buf)-1]='\0';
-        getword(bufy,buf,' ');
-        for(z1=0; z1<=strlen(bufy); z1++) {
-           userfile[z2]=bufy[z1];
-           z2++;
-        }
-        strncat(userfile,":",1);
-        for(z1=0; z1<=strlen(buf); z1++) {
-           userfile[z2]=buf[z1];
-           z2++;
-        }
-        strncat(userfile,":",1);
+      while(fgets(buf,MAXLEN,fp_usr)!=NULL) {
+         buf[strlen(buf)-1]='\0';
+         if(strstr(buf,"\r") != 0) buf[strlen(buf)-1]='\0';
+         getword(bufy,buf,' ');
+         for(z1=0; z1<=strlen(bufy); z1++) {
+            userfile[z2]=bufy[z1];
+            z2++;
+         }
+         strncat(userfile,":",1);
+         for(z1=0; z1<=strlen(buf); z1++) {
+            userfile[z2]=buf[z1];
+            z2++;
+         }
+         strncat(userfile,":",1);
       }
       fclose(fp_usr);
    }
@@ -769,10 +775,10 @@ int main(argc,argv)
       rewind(fp_in);
       recs1=0;
       recs2=0;
+
       while( fgets(bufz,sizeof(bufz),fp_in) != NULL ) recs1++;
       rewind(fp_in);
-
-      printf("SARG: Records in file: %d, reading: %3.2f%%\r",recs1,(float) 0);
+      printf("SARG: Records in file: " OFFSET_STRING ", reading: %3.2f%%\r",recs1,(float) 0);
       fflush( stdout ) ;
    }
    
@@ -781,7 +787,7 @@ int main(argc,argv)
 	if( bool_ShowReadStatistics && ! --OutputNonZero) {
            perc = recs2 * 100 ;
            perc = perc / recs1 ;
-   	   printf("SARG: Records in file: %d, reading: %3.2f%%\r",recs1,perc);
+           printf("SARG: Records in file: " OFFSET_STRING ", reading: %3.2f%%\r",recs1,perc);
            fflush (stdout);
            OutputNonZero = REPORT_EVERY_X_LINES ;
         }
@@ -834,8 +840,13 @@ int main(argc,argv)
               if((str=(char *) strstr(str+1, ".")) != (char *) NULL ) {
                  strcpy(ip,data);
        	         strcpy(elap,"0");
-	         getword(none,bufz,' ');
-	         getword(user,bufz,' ');
+		 if(squid24) {
+                    getword(user,bufz,' ');
+                    getword(none,bufz,' ');
+		 } else {
+	            getword(none,bufz,' ');
+   	            getword(user,bufz,' ');
+		 }
 	         getword(data,bufz,']');
 	         getword(fun,bufz,'"');
 	         getword(fun,bufz,' ');
@@ -843,6 +854,8 @@ int main(argc,argv)
                  getword(code2,bufz,' ');
                  getword(code2,bufz,' ');
                  getword(tam,bufz,' ');
+
+
                  if((str=(char *) strstr(bufz, " ")) != (char *) NULL )
                     getword(code,bufz,' ');
                  else strcpy(code,bufz);
@@ -868,10 +881,10 @@ int main(argc,argv)
 	      getword(tam,bufz,' ');
 	      getword(fun,bufz,' ');
 	      getword(url,bufz,' ');
-              while (strstr(bufz,"%20") != 0) {
-                 getword(warea,bufz,' ');
-                 strcat(url,warea);
-              }
+//              while (strstr(bufz,"%20") != 0) {
+//                 getword(warea,bufz,' ');
+//                 strcat(url,warea);
+//              }
 	      getword(user,bufz,' ');
 	      squid_log=1;
 	   }
@@ -952,7 +965,12 @@ int main(argc,argv)
         if(testvaliduserchar(user))
 	   continue;
 
-        while(strstr(user,"%5c") != 0 || strstr(user,"%20") != 0) {
+        if(strstr(user,"%20") != 0) {
+           getword(w,user,'%');
+           strcpy(user,w);
+        }
+
+        while(strstr(user,"%5c") != 0) {
            getword(w,user,'%');
            strcpy(wuser,user+2);
            sprintf(user,"%s.%s",w,wuser);
@@ -1196,8 +1214,9 @@ int main(argc,argv)
 #endif
 	      totregsg++;
 
-              if(download_flag) {
-                 sprintf(bufz, "%s %s %s %s %s\n",dia,hora,user,ip,download_url);
+              if(download_flag && strstr(code,"DENIED") == 0) {
+                 ndownload = 1;
+                 sprintf(bufz, "%s %s %s %s %s %s\n",dia,hora,user,ip,download_url);
 
 #ifdef LEGACY_WRITE_DOWNLOAD
                  sprintf(tmp3,"%s/sarg/download.unsort",tmp);
@@ -1267,7 +1286,7 @@ int main(argc,argv)
         }
       }
       if( bool_ShowReadStatistics )
-        printf("SARG: Records in file: %d, reading: %3.2f%%\n",recs1, (float) 100 );
+        printf("SARG: Records in file: " OFFSET_STRING ", reading: %3.2f%%\n",recs1, (float) 100 );
    }
 
    if ( fp_Download_Unsort ) 
@@ -1369,10 +1388,6 @@ int main(argc,argv)
    }
 
    if(strstr(ReportType,"denied") != 0) {
-      if(debug) {
-         sprintf(msg,"%s %s",text[54],tmp4);
-         debuga(msg);
-      }
       sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o '%s' '%s'",tmp,tmp5,tmp4);
       system(csort);
       unlink(tmp4);
@@ -1445,7 +1460,7 @@ void getusers(char *pwdfile, int debug)
    bzero(userfile,nreg);
    sprintf(userfile,":");
 
-   while(fgets(buf,255,fp_usr)!=NULL){
+   while(fgets(buf,255,fp_usr)!=NULL) {
      getword(user,buf,':');
      strncat(userfile,user,strlen(user));
      strncat(userfile,":",1);
