@@ -105,7 +105,7 @@ void getlog()
    pclose(fp);
    fclose(tmp);
 
-   sprintf(cmd,"sort -k 4,4 -k 5,5 -o %s %s",template2,template1);
+   sprintf(cmd,"sort -r -k 1,1 -k 2,2 -o %s %s",template2,template1);
    system(cmd);
    unlink(template1);
    datashow(template2);
