@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -34,7 +34,7 @@ void report_day(char *user, int *iprel, int *ipuser)
 
    char data[20];
    char odata[20];
-   char hora[20];
+   char hour[20];
    char elap[20];
    char oelap[20];
    char html[8000];
@@ -43,7 +43,7 @@ void report_day(char *user, int *iprel, int *ipuser)
    char wuser[255];
    char c[ 24 ][20];
    int  count=0;
-   int  ihora=0;
+   int  ihour=0;
    long long int v[ 24 ] = { 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 
 			     0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L };
    long long int t[ 24 ] = { 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 
@@ -146,7 +146,7 @@ void report_day(char *user, int *iprel, int *ipuser)
          count++;
       }
 
-      getword(hora,buf,' ');
+      getword(hour,buf,' ');
       getword(elap,buf,' ');
       elap[strlen(elap)-1]='\0';
 
@@ -174,11 +174,11 @@ void report_day(char *user, int *iprel, int *ipuser)
          strcpy(elap,oelap);
       }
 
-      ihora=atoi(hora);
+      ihour=atoi(hour);
 
-      v[ ihora ]+=my_atoll(elap);
+      v[ ihour ]+=my_atoll(elap);
       tt+=my_atoll(elap);
-      t[ ihora ]+=my_atoll(elap);
+      t[ ihour ]+=my_atoll(elap);
       ttt+=my_atoll(elap);
 
    }
@@ -214,6 +214,5 @@ void report_day(char *user, int *iprel, int *ipuser)
 
    fclose(fp_in);
    fclose(fp_ou);
-
    return;
 }
