@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -78,9 +78,9 @@ void gerarel()
          (strncmp(direntp->d_name,"denied.log",10) == 0) ||
 	 (strncmp(direntp->d_name,"authfail.log.unsort",19) == 0))
          continue;
-      sprintf(tmp3,"%s/%s",tmp,direntp->d_name);
-      if((fp_in=fopen(tmp3,"r"))==NULL){
-         fprintf(stderr, "SARG: (report) %s: %s\n",text[45],tmp);
+         sprintf(tmp3,"%s/%s",tmp,direntp->d_name);
+         if((fp_in=fopen(tmp3,"r"))==NULL){
+            fprintf(stderr, "SARG: (report) %s: %s\n",text[45],tmp);
          exit(1);
       }
     
@@ -286,7 +286,7 @@ void gerarel()
 
       if(strcmp(accuser,oldaccuser) != 0) {
          strcpy(wdirname,dirname);
-         totaliza_day(tmp,oldaccuser,indexonly);
+         day_totalize(tmp,oldaccuser,indexonly);
       }
 
       strcpy(oldaccuser,accuser);
@@ -306,11 +306,13 @@ void gerarel()
    if(strstr(oldacccode,"DENIED") != 0)
       sprintf(oldmsg,"%s",text[46]);
    strcpy(wdirname,dirname);
+   if(strlen(oldaccuser) == 0)
+      strcpy(oldaccuser,accuser);
    gravatmpf(oldaccuser,wdirname,oldurl,nacc,nbytes,oldmsg,nelap,indexonly,incache,oucache);
    strcpy(wdirname,dirname);
    gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
    strcpy(wdirname,dirname);
-   totaliza_day(tmp,oldaccuser,indexonly);
+   day_totalize(tmp,oldaccuser,indexonly);
 
    tmpsort();
 
@@ -363,7 +365,8 @@ void gerarel()
       index_only(wdirname, debug);
    }
 
-   removetmp(dirname);
+   if(strlen(email) < 0)
+      removetmp(dirname);
 
    return;
 }
@@ -568,7 +571,7 @@ void gravager(char *dirname, char *user, long long int nacc, char *url, long lon
    FILE *fp_ou;
 
    strcat(dirname,"/");
-   strcat(dirname,"general");
+   strcat(dirname,"sarg-general");
    
    if((fp_ou=fopen(dirname,"a"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],dirname);
