@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -58,9 +58,9 @@ void smartfilter_report()
    strup(smartheader);
 
    sprintf(smart_in,"%s/smartfilter.unsort",dirname);
-   sprintf(sites,"%s/sites",dirname);
+   sprintf(sites,"%s/sarg-sites",dirname);
    sprintf(smart_ou,"%s/smartfilter.log",dirname);
-   sprintf(per,"%s/period",dirname);
+   sprintf(per,"%s/sarg-period",dirname);
    sprintf(report,"%s/smartfilter.html",dirname);
 
    if ((fp_in = fopen(per, "r")) == 0) {
