@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -118,6 +118,11 @@ void sort_users_log(char *tmp, int debug)
    char wname2[MAXLEN];
    char wdname[MAXLEN];
 
+   if(debug) {
+      sprintf(msg,"%s",text[138]);
+      debuga(msg);
+   }
+
    sprintf(wtmp,"%s/sarg",tmp);
 
    dirp = opendir(wtmp);
@@ -139,11 +144,6 @@ void sort_users_log(char *tmp, int debug)
          goto strip_unsort;
       }
 
-      if(debug) {
-         sprintf(msg,"%s %s/%s.unsort",text[54],wtmp,user);
-         debuga(msg);
-      }
-
       if(strcmp(direntp->d_name,"download.unsort") == 0)
          sprintf(csort,"sort -T %s -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o '%s/%s.log' '%s/%s.unsort'",
 					tmp, wtmp, user, wtmp, user);
