@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -58,11 +58,11 @@ void topsites()
    if(strcmp(Privacy,"yes") == 0)
       return;
 
-   sprintf(general,"%s/general",dirname);
-   sprintf(sites,"%s/sites",dirname);
-   sprintf(general2,"%s/general2",dirname);
-   sprintf(general3,"%s/general3",dirname);
-   sprintf(per,"%s/period",dirname);
+   sprintf(general,"%s/sarg-general",dirname);
+   sprintf(sites,"%s/sarg-sites",dirname);
+   sprintf(general2,"%s/sarg-general2",dirname);
+   sprintf(general3,"%s/sarg-general3",dirname);
+   sprintf(per,"%s/sarg-period",dirname);
 
    if (strstr(ReportType,"topusers") == 0)
       sprintf(report,"%s/index.html",dirname);
@@ -198,11 +198,14 @@ void topsites()
    fputs(url,fp_ou);
 
    regs=1;
+   ntopsites = 0;
 
    while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
       if(regs>atoi(TopSitesNum))
          break;
       getword(nacc,buf,' ');
+      if (atoi(nacc) == 0) continue;
+
       getword(nbytes,buf,' ');
       getword(ntime,buf,' ');
       getword(url,buf,' ');
@@ -213,7 +216,7 @@ void topsites()
 
       sprintf(wwork1,"%s",fixnum(twork1,1));
       sprintf(wwork2,"%s",fixnum(twork2,1));
-      sprintf(wwork3,"%s",fixnum(twork3,1));
+      sprintf(wwork3,"%s",fixtime(twork3,1));
 
       if(strlen(BlockIt) > 0)
          sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"../images/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,url);
