@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -56,12 +56,13 @@ int topuser()
    strcpy(top2,dirname);
    strcpy(top3,dirname);
    strcpy(tusr,dirname);
-   strcat(wger,"/general");
+   strcat(wger,"/sarg-general");
    strcat(top1,"/top");
    strcat(top2,"/top.tmp");
-   strcat(tusr,"/users");
+   strcat(tusr,"/sarg-users");
    strcat(top3,"/index.html");
 
+   ntopuser = 0;
    if((fp_in=fopen(wger,"r"))==NULL) {
     fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],wger);
     exit(1);
@@ -180,7 +181,7 @@ int topuser()
  */
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/period");
+   strcat(arqper,"/sarg-period");
 
    if ((fp_in = fopen(arqper, "r")) == 0) {
       fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],arqper);
@@ -220,7 +221,7 @@ int topuser()
    if(strstr(ReportType,"sites_users") != 0 && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"siteuser.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[85]);
    if(dansguardian_count) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"dansguardian.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[128]);
    if(squidguard_count) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"squidguard.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[122]);
-   if (strstr(ReportType,"downloads") != 0 && download_count && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"download.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[125]);
+   if (strstr(ReportType,"downloads") != 0 && download_count && strcmp(Privacy,"yes") != 0 && ndownload) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"download.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[125]);
    if (strstr(ReportType,"denied") != 0 && denied_count && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"denied.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[118]);
    if (strstr(ReportType,"auth_failures") != 0 && authfail_count && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"authfail.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[117]);
    if(smartfilter) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"smartfilter.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[116]);
@@ -295,9 +296,14 @@ int topuser()
 
    fprintf(fp_top3,"<tr><th %s>%s</th><th %s></th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s %s>%s%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th></tr>\n",hbc1,val1,hbc1,hbc2,val2,hbc3,val3,hbc4,val4,hbc9,val11,hbc5,val9,val5,val10,hbc6,val6,hbc7,val7,hbc8,val8);
 
-   fscanf(fp_top1,"%s%s%s%s%s%s",user,nbytes,nacc,elap,incac,oucac);
+   ntopuser = 0;
 
+   fscanf(fp_top1,"%s%s%s%s%s%s",user,nbytes,nacc,elap,incac,oucac);
    while(!feof(fp_top1)) {
+      if(atoi(nacc) < 1) {
+         fscanf(fp_top1,"%s%s%s%s%s%s",user,nbytes,nacc,elap,incac,oucac);
+         continue;
+      } else ntopuser = 1;
       if(atoi(TopUsersNum) > 0 && topcount >= atoi(TopUsersNum)) goto final;
       strcpy(user2,user);
       tnbytes=my_atoll(nbytes);
@@ -368,7 +374,7 @@ int topuser()
       }
 
 //      if(UserTabFile[0] != '\0' && strstr(user2,".") != 0) {
-      if(UserTabFile[0] != '\0') {
+      if(UserTabFile[0] != '\0' && strcmp(user2,"TOTAL") != 0) {
          sprintf(warea,":%s:",user2);
          if((str=(char *) strstr(userfile,warea)) != (char *) NULL ) {
             z1=0;
@@ -391,7 +397,7 @@ int topuser()
       my_lltoa(twork,nacc,0);
       sprintf(wwork1,"%s",fixnum(twork,1));
       sprintf(wwork2,"%s",fixnum(tnbytes,1));
-      sprintf(wwork3,"%s",fixnum(tnelap,1));
+      sprintf(wwork3,"%s",fixnum2(tnelap,1));
 
       sprintf(val1,"%d",posicao);
 #ifdef HAVE_GD
@@ -484,7 +490,7 @@ int topuser()
 
 	 sprintf(wwork1,"%s",fixnum(ttnacc,1));
 	 sprintf(wwork2,"%s",fixnum(ttnbytes,1));
-	 sprintf(wwork3,"%s",fixnum(ttnelap,1));
+	 sprintf(wwork3,"%s",fixnum2(ttnelap,1));
 
          strcpy(hbc1,"class=\"header2\"");
          strcpy(hbc2,"class=\"header2\"");
@@ -546,7 +552,7 @@ int topuser()
    twork2=ttnelap/totuser;
    sprintf(wwork1,"%s",fixnum(twork,1));
    sprintf(wwork2,"%s",fixnum(tnbytes,1));
-   sprintf(wwork3,"%s",fixnum(twork2,1));
+   sprintf(wwork3,"%s",fixnum2(twork2,1));
 
    if(strstr(TopUserFields,"CONNECT") == 0) {
       bzero(wwork1, 255);
@@ -571,8 +577,10 @@ int topuser()
       bzero(hbc6, 30);
    }
 
-   if((strstr(ReportType,"date_time") != 0 && strstr(TopUserFields,"AVERAGE") != 0)) fprintf(fp_top3,"<tr><td></td><th></th><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
-   else if(strstr(TopUserFields,"AVERAGE") != 0) fprintf(fp_top3,"<tr><td></td><th></th><td></td><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
+   if(ntopuser) {
+      if((strstr(ReportType,"date_time") != 0 && strstr(TopUserFields,"AVERAGE") != 0)) fprintf(fp_top3,"<tr><td></td><th></th><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
+      else if(strstr(TopUserFields,"AVERAGE") != 0) fprintf(fp_top3,"<tr><td></td><th></th><td></td><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
+   }
 
    if(strlen(UserAgentLog) > 0) {
       fputs("<tr><td></td></tr>\n",fp_top3);
