@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -25,7 +25,7 @@
 
 #include "include/conf.h"
 
-void totaliza_day(const char *tmp, char *user, int indexonly)
+void day_totalize(const char *tmp, char *user, int indexonly)
 {
 
    FILE *fp_in, *fp_ou;
@@ -88,7 +88,7 @@ void totaliza_day(const char *tmp, char *user, int indexonly)
          regs++;
       }
 
-      if(strcmp(hora,ohora) != 0) {
+      if(strcmp(hora,ohora) != 0 || strcmp(data,odata) != 0) {
          if(tused > telap)
             tused=telap;
 
