@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -40,7 +40,7 @@ int totalger(const char *dirname, int debug, const char *outdir)
    char incac[15], oucac[15];
 
    strcpy(wger,dirname);
-   strcat(wger,"/general");
+   strcat(wger,"/sarg-general");
 
    if((fp_in=fopen(wger,"r"))==NULL) {
       fprintf(stderr, "SARG: (totger) %s: %s\n",text[45],wger);
@@ -63,7 +63,7 @@ int totalger(const char *dirname, int debug, const char *outdir)
    fclose(fp_in);
 
    strcpy(wger,dirname);
-   strcat(wger,"/general");
+   strcat(wger,"/sarg-general");
 
    if((fp_ou=fopen(wger,"a"))==NULL) {
     fprintf(stderr, "SARG: (totger) %s: %s\n",text[45],wger);
