@@ -1,6 +1,6 @@
 /*
  * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
- *                                                            1998, 2006
+ *                                                            1998, 2007
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -501,6 +501,50 @@ char *fixnum(long long int value, int n)
 }
 
 
+char *fixnum2(long long int value, int n)
+#define MAXIMO 1024
+{
+   char num[MAXIMO];
+   char buf[MAXIMO * 2];
+   char *pbuf;
+   char ret[MAXIMO * 2];
+   char *pret;
+   register int i, j, k;
+   static char abbrev[30];
+      
+   my_lltoa(value, num, 0);
+   bzero(buf, MAXIMO*2);
+
+   pbuf = buf;
+   pret = ret;
+   k = 0;
+
+   for ( i = strlen(num) - 1, j = 0 ; i > -1; i--) {
+      if ( k == 2 && i != 0 )  {
+         k = 0;
+         pbuf[j++] = num[i];
+         if(strcmp(UseComma,"yes") == 0)
+            pbuf[j++] = ',';
+         else pbuf[j++] = '.';
+         continue;
+      }
+      pbuf[j] = num[i];
+      j++;
+      k++;
+   }
+
+   pret[0]='\0';
+
+   for ( i = strlen(pbuf) - 1, j = 0 ; i > -1; i--, j++)
+      pret[j] = pbuf[i];
+
+      pret[j] = '\0';
+
+      return pret;
+}
+
+
+
 void buildhref(char * href)
 {
    char whref[MAXLEN];
@@ -550,10 +594,13 @@ void obtdate(char *dirname, char *name, char *data)
    FILE *fp_in;
    char wdir[MAXLEN];
 
-   sprintf(wdir,"%s%s/date",dirname,name);
+   sprintf(wdir,"%s%s/sarg-date",dirname,name);
    if ((fp_in = fopen(wdir, "r")) == 0) {
-      data[0]='\0';
-      return;
+      sprintf(wdir,"%s%s/date",dirname,name);
+      if ((fp_in = fopen(wdir, "r")) == 0) {
+         data[0]='\0';
+         return;
+      }
    }
 
    fgets(data,80,fp_in);
@@ -571,10 +618,13 @@ void obtuser(char *dirname, char *name, char *tuser)
    FILE *fp_in;
    char wdir[MAXLEN];
 
-   sprintf(wdir,"%s%s/users",dirname,name);
-   if((fp_in=fopen(wdir,"r"))==NULL){    
-      tuser[0]='\0';
-      return;
+   sprintf(wdir,"%s%s/sarg-users",dirname,name);
+   if((fp_in=fopen(wdir,"r"))==NULL) {    
+      sprintf(wdir,"%s%s/users",dirname,name);
+      if((fp_in=fopen(wdir,"r"))==NULL) {    
+         tuser[0]='\0';
+         return;
+      }
    }
 
    fgets(tuser,20,fp_in);
@@ -594,11 +644,13 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
    long long int med=0;
    long long int wtuser=0;
 
-   sprintf(wdir,"%s%s/general",dirname,name);
-
+   sprintf(wdir,"%s%s/sarg-general",dirname,name);
    if ((fp_in = fopen(wdir, "r")) == 0) {
-      tbytes=0;
-      return;
+      sprintf(wdir,"%s%s/general",dirname,name);
+      if ((fp_in = fopen(wdir, "r")) == 0) {
+         tbytes=0;
+         return;
+      }
    }
 
    while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
@@ -637,7 +689,7 @@ void gperiod()
 
    strcpy(wdirname,dirname);
    strcat(wdirname,"/");
-   strcat(wdirname,"period");
+   strcat(wdirname,"sarg-period");
 
    if((fp_ou=fopen(wdirname,"w"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
@@ -792,7 +844,7 @@ void vrfydir(char *dir, char *per1, char *addr, char *site, char *us, char *form
    sprintf(images,"%simages",outdir);
    mkdir(images,0755);
 
-   sprintf(wdir,"date >%s/%s",dirname,"date");
+   sprintf(wdir,"date >%s/%s",dirname,"sarg-date");
    system(wdir);
 
    sprintf(per2,"%s/images",SYSCONFDIR);
@@ -1006,12 +1058,12 @@ void removetmp(char *outdir)
       return;
    } else {
       if(debug) {
-         sprintf(msg,"%s: general, period",text[82]);
+         sprintf(msg,"%s: sarg-general, sarg-period",text[82]);
          debuga(msg);
       }
-      sprintf(warea,"%s/general",outdir);
+      sprintf(warea,"%s/sarg-general",outdir);
       if((fp_in=fopen(warea,"r"))==NULL){
-         fprintf(stderr, "SARG: (removetmp) %s: %s\n",text[45],warea);
+         fprintf(stderr, "===SARG: (removetmp) %s: %s\n",text[45],warea);
          exit(1);
       }
       while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
@@ -1025,7 +1077,7 @@ void removetmp(char *outdir)
       }
       fputs(buf,fp_in);
       fclose(fp_in);
-      sprintf(warea,"%s/period",outdir);
+      sprintf(warea,"%s/sarg-period",outdir);
       unlink(warea);
    }
   
